@@ -204,7 +204,7 @@ const Application = new Lang.Class({
         settings.connect('changed::night-mode', Lang.bind(this,
             function() {
                 let state = settings.get_value('night-mode');
-                if (state.get_boolean()[0] != action.state.get_boolean()[0])
+                if (state.get_boolean() != action.state.get_boolean())
                     action.state = state;
 
                 let gtkSettings = Gtk.Settings.get_default();
@@ -236,7 +236,6 @@ const Application = new Lang.Class({
 
     _onActionNightMode: function(action) {
         let state = action.get_state();
-        action.change_state(GLib.Variant.new('b', !state.get_boolean()));
         settings.set_value('night-mode', GLib.Variant.new('b', !state.get_boolean()));
     },
 
